@@ -50,11 +50,24 @@ class RstFile(object):
         self.indents = []
         self.line_started = False
 
+        self.current_index = -1
+
         self.current = self
 
     def __repr__(self):
         return '"%s"' % '\\n'.join(self.lines)
 
+    def _addline(self, line):
+        if self.current_index == -1:
+            self.lines.append(line)
+        else:
+            self.lines.insert(self.current_index, line)
+        if self.current_index != -1:
+            self.current_index += 1
+
+    def moveto(self, index):
+        self.current_index = index
+
     @property
     def depth(self):
         return len(self.indents)
@@ -66,7 +79,7 @@ class RstFile(object):
         if line != '':
             indent = ''.join(self.indents)
             line = indent + line
-        self.lines.append(line)
+        self._addline(line)
         self.line_started = True
             
     def append(self, line=''):
@@ -81,7 +94,7 @@ class RstFile(object):
         if line != '':
             indent = ''.join(self.indents)
             line = indent + line
-        self.lines.append(line)
+        self._addline(line)
 
     def heading(self, text, depth):
         self.current._heading(text, depth)
@@ -102,7 +115,7 @@ class RstFile(object):
 
     def _end_bloc(self):
         self.indents.pop()
-        self.lines.append('')
+        self._addline('')
 
     def directive(self, name, *args, **kw):
         self.current._directive(name, *args, **kw)
